function [scat_enhance, abs_enhance] = ...
	 aspherical_enhancement(epsilon, aspect)
  % Compute the scattering and absorption enhancement for small
  % hexagonal columns and plates relative to spheres, where epsilon is
  % the dielectric constant and aspect is the aspect ratio with values
  % less than 1 indicating plates and greater than 1 indicating
  % columns. In the Rayleigh-Gans approximation, this may also be used
  % to scale the enhancement of the overall scattering and absorption
  % by aggregates composed of hexagonal monomers, provided the
  % monomers are much smaller than the wavelength.

  % Westbrook (QJ 2014) uses the opposite convention for aspect ratio
  w = 1./aspect;
  % Westbrook (QJ 2014) equations 12 and 13
  Lz = 0.5.*((1-3.0./w)./(1+3.0./w) + 1.0);
  Lx = 0.25.*((1-0.5.*w.^0.9)./(1+0.5.*w.^0.9) + 1.0);
  % Polarizability along the principal axes, removing the volume term
  % (implicitly Xy=Xx)
  Xz = (epsilon-1)./(Lz.*(epsilon-1) + 1);
  Xx = (epsilon-1)./(Lx.*(epsilon-1) + 1);
  % Claussius-Mossotti formula for spheres
  K = (epsilon-1)./(epsilon+2);
  K29 = 9.*abs(K).^2;
  % Enhancement assumes random orientation, so the three
  % polarizabilities (Xy=Xx) are weighted equally.
  scat_enhance = abs(Xz.^2./3 + Xx.^2.*2./3)./K29;
  abs_enhance  = imag(-sqrt(Xz.^2./3 + Xx.^2.*2./3))./(3.*imag(-K));
