%COMPARE_ICE_SCATTERING_MODELS
%   Script to compare four scattering models for ice aggregates:
%   Rayleigh-Gans spheres, Rayleigh-Gans spheroids, the Self-Similar
%   Rayleigh-Gans Approximation of Hogan and Westbrook (2014) / Hogan
%   et al. (2017) and the Rayleigh approximation.
%
%   This file was written by Robin Hogan, but no copyright is
%   asserted: this file is in the public domain.  Therefore, copying
%   and distribution of this file, with or without modification, and
%   merging all or part of this file into other works, are permitted
%   in any medium without royalty. This file is offered as-is, without
%   any warranty.

% Do we use older settings, or the newer Hogan et al. (2017)?
use_hogan_westbrook_2014 = 0;

% Particle sizes in terms of maximum dimension
dD= 20e-6;
D = dD:dD:0.05;

% Add an irrational number to the wavelength to minimize the likelihood
% of numerical issues when size is an exact multiple of wavelength
wavelength = 0.00319 + pi.*1e-7;

% Dielectric constant of solid ice at 94 GHz and 0 degrees C
dielectric_const = 3.15 + 0.00964i;

% Longest particle dimension
Dlong = D;

% Aspect ratio
aspect = 0.6;

% Alternative aspect ratio: if we want to compare aspect ratio (as in Hogan
% and Westbrook) but keep the mass the same then the smaller, alternative
% aspect ratio will be used to determine the threshold mass for small
% particles to prevent them being denser than solid ice
aspect_alt = 0.5;

% The shortest particle dimension, assumed to be in the vertical, is what
% is needed by the Self-Similar Rayleigh Gans approximation
Dshort = Dlong.*aspect;

% Brown and Francis (1995) mass-size relationship, but using Hogan et al.'s
% (2012) conversion to be in terms of the longest particle dimension, since
% the original BF95 expression was in terms of the "mean" dimension, which
% was the mean of the maximum and minimum dimensions of particles as viewed
% by their aircraft instruments
mass = 0.012 .* Dlong.^1.9;

% Density of solid ice (kg m-3)
rho0 = 917.0;

% The two maximum possible particle masses found by assuming oblate
% spheroids of the specified aspect ratio with densities of solid ice
mass_max = (pi*rho0/6) .* Dlong.^3.*aspect;
mass_max_alt = (pi*rho0/6) .* Dlong.^3.*aspect_alt;

% Ensure that the mass does not exceed either of the two maxima
index = find(mass_max < mass);
mass(index) = mass_max(index);
index = find(mass_max_alt < mass);
mass(index) = mass_max_alt(index);

% Volume of solid ice in the particle
volume = mass./rho0;

if use_hogan_westbrook_2014
  kappa = 0.19;
  beta  = 0.23;
  gamma = 5.0/3.0;
  zeta1 = 1.0;
  scat_enhancement = 1.0;
  abs_enhancement  = 1.0;
else
  kappa = 0.09;
  beta  = 0.55;
  gamma = 2.0;
  zeta1 = 0.28;
  monomer_aspect_ratio = 4.0;
  [scat_enhancement, abs_enhancement] ...
     = aspherical_enhancement(dielectric_const, monomer_aspect_ratio);
end

% Compute the backscatter cross section of the particles using the
% Self-Similar Rayleigh-Gans Approximation with the parameters for
% aggregates of bullet rosettes reported by Hogan and Westbrook (2014)
bcs_ssrg = scat_enhancement ...
   * self_similar_rayleigh_gans(wavelength, dielectric_const, Dshort, ...
					volume, 0.19, 0.23, 5/3, 1.0);

% Use Rayleigh-Gans theory for homogeneous ice-air spheres and
% spheroids. Note that in Hogan and Westbrook instead of Rayleigh-Gans
% for spheres, Mie theory was used with the Maxwell-Garnet mixing rule,
% which gives slightly different results.
bcs_rg_sphere = rayleigh_gans(wavelength, dielectric_const, Dlong, volume);
bcs_rg_spheroid = rayleigh_gans(wavelength, dielectric_const, Dshort, volume);

% Finally the backscatter cross section for Rayleigh theory
bcs_rayleigh = rayleigh(wavelength, dielectric_const, volume);

% Longest dimension in mm
Dlong_mm = Dlong.*1000;

% Obtain Field et al. (200x) size distributions, where "mode" can be
% "2005", "2007tropical" or "2007midlatitude"
field_mode = '2005';
n = field_size_distribution(field_mode, 0, D);

% Number of size distributions (m2 refers to the second moment)
n_m2 = size(n,2);

% Ice water content (kg m-3)
IWC = sum(n.*(mass(:)*ones(1,n_m2))).*dD;
IWC_g_m3 = IWC.*1000.0;

% Note that we use the convention that all radar wavelengths should
% measure the same reflectivity factor in Rayleigh-scattering ice cloud,
% referenced back to cm-wavelength radar.
Zfactor = 1e18.*wavelength.^4./(0.93.*pi.^5);

Z_ssrg = 10.0.*log10(sum(n.*(bcs_ssrg(:)*ones(1,n_m2))).*dD.*Zfactor);
Z_rg_spheroid = 10.0.*log10(sum(n.*(bcs_rg_spheroid(:)*ones(1,n_m2))).*dD.*Zfactor);
Z_rg_sphere = 10.0.*log10(sum(n.*(bcs_rg_sphere(:)*ones(1,n_m2))).*dD.*Zfactor);
Z_rayleigh = 10.0.*log10(sum(n.*(bcs_rayleigh(:)*ones(1,n_m2))).*dD.*Zfactor);

% Plot the scattering for individual particles
figure(2)
clf
set(gcf,'defaultaxesfontsize',18,'defaultlinelinewidth',1)
loglog(Dlong_mm, bcs_rg_sphere, 'b');
hold on
loglog(Dlong_mm, bcs_rg_spheroid, 'm');
loglog(Dlong_mm, bcs_ssrg, 'r');
loglog(Dlong_mm, bcs_rayleigh, 'k');
xlabel('Maximum particle dimension (mm)');
ylabel('Backscatter cross section (m^2)');
title('\bf(a) Individual particles')
axis([5e-2 5e1 1e-14 1e-4]);
set(gca,'ytick',10.^[-16:2:0],'xtick',10.^[-1:1]);
grid on
set(gca,'yminortick','off');
h=legend('Rayleigh-Gans spheres',...
       ['Rayleigh-Gans spheroids \alpha=' num2str(aspect)],...
       ['Self-Similar Rayleigh-Gans \alpha=' num2str(aspect)], ...
       'Rayleigh', 2);
set(h,'fontsize',16);

% Plot the scattering for distributions of particles
figure(1)
clf
set(gcf,'defaultaxesfontsize',18,'defaultlinelinewidth',1)
plot(Z_rg_sphere, IWC_g_m3,'b');
hold on
plot(Z_rg_spheroid, IWC_g_m3,'m');
plot(Z_ssrg, IWC_g_m3,'r');
plot(Z_rayleigh, IWC_g_m3,'k');
set(gca,'yscale','log')
axis([-30 20 0.5e-3 1e0]);
%set(gca,'xtick',[-40:10:30], 'ytick',10.^[-15:1]);
grid on
xlabel('Reflectivity factor (dBZ)');
ylabel('Ice water content (g m^{-3})');
title(['\bf(b) Distributions of particles'])
h=legend('Rayleigh-Gans spheres',...
       ['Rayleigh-Gans spheroids \alpha=' num2str(aspect)],...
       ['Self-Similar Rayleigh-Gans \alpha=' num2str(aspect)], ...
       'Rayleigh', 4);
set(h,'fontsize',16);
