function n = field_size_distribution(mode, T, D, M2)
%FIELD_SIZE_DISTRIBUTION
%   Compute ice size distributions from the parameterization of either Field
%   et al. (2005) or Field et al. (2007).  The arguments are:
%      mode   Can be one of "2005", "2007tropical" or "2007midlatitude"
%      T      Temperature (degrees C) - must be a scalar
%      D      Particle maximum dimension (m) - can be a vector
%      M2     Second moment of the size distribution (m3) - can be a
%             vector, and can be omitted to get the default values
%      n      Number concentration (m-4) in the form of a matrix of size
%             length(D) x length(M2)
%
%   This file was written by Robin Hogan, but no copyright is asserted: this
%   file is in the public domain.  Therefore, copying and distribution of
%   this file, with or without modification, and merging all or part of this
%   file into other works, are permitted in any medium without royalty.
%   This file is offered as-is, without any warranty.

% Default second moment values
if nargin < 4
  M2 = 10.^[-5:0.1:-1.3]; 
  M2 = 10.^[-5:0.1:-0.5]; 
end

% We want the third moment
moment = 3;

if strncmp(lower(mode), '2005', 4)
  % Field et al. (2005)
  A = 10.^(5.065339 - 0.062659.*T -3.032362.*moment + 0.029469.*T.*moment ...
           -0.000285.*T.^2 +0.31255.*moment.^2 + 0.000204.*T.^2.*moment ...
           +0.003199.*T.*moment.^2 -0.015952.*moment.^3);
  B = 0.476221 - 0.015896.*T + 0.165977.*moment + 0.007468.*T.*moment ...
      -0.000141.*T.^2 +0.060366.*moment.^2 +0.000079.*T.^2.*moment ...
      +0.000594.*T.*moment.^2 -0.003577.*moment.^3;
  M3 = A.*M2.^B;
elseif strncmp(lower(mode),'2007', 4)
  % Field, Heymsfield and Bansemer (2007)
  A = exp(13.6-7.7.*moment+0.479.*moment.^2);
  B = -0.0361+0.0151.*moment+0.00149.*moment.^2;
  C = 0.807+0.00581.*moment+0.0457.*moment.^2;
  M3 = A.*exp(B.*T).*M2.^C;
else 
  error(['Mode "' mode '" not understood (should be 2005, 2007tropical or 2007midlatitude)'])
end

% Length scale derived from 2nd and 3rd moments
L23 = M3./M2;

% Normalized number concentration from 2nd and 3rd moments
N023 = M2.^4./M3.^3;

n = zeros(length(D), length(M2));

% Loop over mean sizes
for im = 1:length(M2)
  x = D(:)./L23(im);

  if strncmp(lower(mode), '2005', 4)
    n(:, im) = N023(im).*(490.6.*exp(-20.78.*x)+17.46.*x.^0.6357.*exp(-3.290.*x));
  elseif strncmp(lower(mode(5:end)), 'tropical',4)
    n(:, im) = N023(im).*(152.*exp(-12.4.*x)+3.28.*x.^-0.78.*exp(-1.94.*x));
  elseif strncmp(lower(mode(5:end)), 'midlatitude', 6)
    n(:, im) = N023(im).*(141.*exp(-16.8.*x)+102.*x.^2.07.*exp(-4.82.*x));
  else
    error(['Mode "' mode '" not understood (should be 2005, 2007tropical or 2007midlatitude)'])
  end
end
